******************************************************************************
*
*                   SPICE Transistor Model Parameter Library
*                             0.5 um CMOS Process
*
******************************************************************************
*
* 05/24/96  Obtained transistor model parameters from the web.
*           Greg Edlund
*
* 05/22/98  Applied process tolerances to create fast and slow libraries:
*           Greg Edlund
* 
*           param   fast   slow
*           U0       +5%    -5%
*           VT0     -15%   -15%
*           TOX      -5%    +5%
*           NSUB    -20%   +20%
*           THETA   +20%   -20%
*
* 07/14/01  Created ESD diode model from rough estimates based on
*           Motorola Application Note AN1578, "MECL 10H SPICE Kit."
*           Greg Edlund
*
******************************************************************************
*
* param   description                                    units
* -----   -----------                                    -----
* KAPPA   saturation field factor                        1/V
* LD      lateral diffusion                              m
* TOX     gate oxide thickness                           m
* VMAX    maximum carrier drift velocity                 m/s
* XJ      metallurgical junction depth                   m
* NFS     fast surface state density                     1/Vcm2
* NSUB    bulk surface doping                            1/cm3
* PHI     surface inversion potential                    V
* VTO     zero-bias threshold voltage                    V
* THETA   mobility degradation factor                    1/V
* UO      low-field bulk mobility                        cm2/Vs
* RSH     drain and source diffusion sheet resistance    Ohm/sq
* CJ      zero-bias bulk junction capacitance            F/m2
* MJ      bulk junction grading coefficient              unitless
* PB      bulk junction contact potential                V
* CGBO    gate-bulk overlap capacitance                  F/m
* CGDO    gate-drain overlap capacitance                 F/m
* CGSO    gate-source overlap capacitance                F/m
*
*
* basic empirical model cmosparameters:  KAPPA, LD, TOX, VMAX, XJ
* threshold voltage parameters:  NFS, NSUB, PHI, VTO
* mobility parameters:  THETA, UO
* resistance parameters:  RSH
* capacitance parameters:  CJ, MJ, PB, CJBO, CJDO, CJSO
*
******************************************************************************



*----------------------------------------------------------------------------*
* TRANSISTOR MODEL PARAMETERS
*----------------------------------------------------------------------------*

.MODEL CMOSN NMOS
+LEVEL =3
+KAPPA =   2.90E-02
+LD    =   4.73E-08
+TOX   =   9.60E-09
+VMAX  =   2.00E+05
+XJ    =   2.00E-07
+NFS   =   5.91E+11
+NSUB  =   1.39E+17
+PHI   =   7.00E-01
+VTO   =   6.57E-01
+THETA =   2.68E-01
+UO    =   5.46E+02
+RSH   =   3.51E+01
+CJ    =   5.62E-04
+MJ    =   5.59E-01
+PB    =   9.90E-01
+CGBO  =   4.02E-10
+CGDO  =   3.05E-10
+CGSO  =   3.05E-10


.MODEL CMOSP PMOS
+LEVEL =3
+KAPPA =   7.96E+00
+LD    =   3.51E-08
+TOX   =   9.60E-09
+VMAX  =   2.54E+05
+XJ    =   2.00E-07
+NFS   =   6.50E+11
+NSUB  =   8.51E+16
+PHI   =   7.00E-01
+VTO   =  -9.21E-01
+THETA =   1.81E-01
+UO    =   1.35E+02
+RSH   =   1.10E-01
+CJ    =   9.35E-04
+MJ    =   4.68E-01
+PB    =   9.90E-01
+CGBO  =   3.76E-10
+CGDO  =   2.39E-10
+CGSO  =   2.39E-10

*----------------------------------------------------------------------------*
* ESD DIODE MODEL PARAMETERS
*----------------------------------------------------------------------------*

.include diode.inc


